Summary: Bloom filter for probabilistic set membership. Copyright (c) YOAB. All rights reserved.
Provides a space-efficient probabilistic data structure for fast negative lookups. When the filter says a key is not present, it is definitely not present. When it says a key might be present, there is a small probability of a false positive.
Structs
- Bloom
Filter - A space-efficient probabilistic data structure for set membership.